## 0.5.0.20260408 (2026-04-08)

Use dashes instead of underscores for METADATA.toml field names ([#15614](https://github.com/python/typeshed/pull/15614))

## 0.5.0.20250828 (2025-08-28)

[PyMeeus] Add stubs ([#14649](https://github.com/python/typeshed/pull/14649))

